slider - GooeyPy Docs

Documentation
Overview
gui

- app
- widget
- styleset
- effects

widgets

- label
- button
- input
- slider
- container
- box
- selectbox
- textblock
- image

- HSlider
- VSlider

# HSlider

HSlider([value, [min_value, [length, [step]]]]]) -> Slider widget

value
  Initial value
orient
  Can be vertical or horizontail (default)
min_value
  This is the lowest value the slider can go to. Defaults to 0.
length
  The largest value the slider can go to would be min_value+length. Defaults to min_value.
step
  If step is True (default) the value will always be an int. Otherwise it won't round off the decimal.

# VSlider

VSlider([value, [min_value, [length, [step]]]]]) -> Slider widget

Just like HSlider except displays vertically.